@@ -50,6 +50,7 @@ from google.protobuf import timestamp_pb2  # type: ignore
 from .transports.base import AppConnectionsServiceTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc import AppConnectionsServiceGrpcTransport
 from .transports.grpc_asyncio import AppConnectionsServiceGrpcAsyncIOTransport
+from .transports.rest import AppConnectionsServiceRestTransport
 
 
 class AppConnectionsServiceClientMeta(type):
@@ -65,6 +66,7 @@ class AppConnectionsServiceClientMeta(type):
     )  # type: Dict[str, Type[AppConnectionsServiceTransport]]
     _transport_registry["grpc"] = AppConnectionsServiceGrpcTransport
     _transport_registry["grpc_asyncio"] = AppConnectionsServiceGrpcAsyncIOTransport
+    _transport_registry["rest"] = AppConnectionsServiceRestTransport
 
     def get_transport_class(
         cls,
@@ -414,6 +416,9 @@ class AppConnectionsServiceClient(metaclass=AppConnectionsServiceClientMeta):
             transport (Union[str, AppConnectionsServiceTransport]): The
                 transport to use. If set to None, a transport is chosen
                 automatically.
+                NOTE: "rest" transport functionality is currently in a
+                beta state (preview). We welcome your feedback via an
+                issue in this library's source repository.
             client_options (google.api_core.client_options.ClientOptions): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
@@ -507,6 +512,13 @@ class AppConnectionsServiceClient(metaclass=AppConnectionsServiceClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import beyondcorp_appconnections_v1
 
             def sample_list_app_connections():
@@ -616,6 +628,13 @@ class AppConnectionsServiceClient(metaclass=AppConnectionsServiceClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import beyondcorp_appconnections_v1
 
             def sample_get_app_connection():
@@ -720,6 +739,13 @@ class AppConnectionsServiceClient(metaclass=AppConnectionsServiceClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import beyondcorp_appconnections_v1
 
             def sample_create_app_connection():
@@ -864,6 +890,13 @@ class AppConnectionsServiceClient(metaclass=AppConnectionsServiceClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import beyondcorp_appconnections_v1
 
             def sample_update_app_connection():
@@ -1002,6 +1035,13 @@ class AppConnectionsServiceClient(metaclass=AppConnectionsServiceClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import beyondcorp_appconnections_v1
 
             def sample_delete_app_connection():
@@ -1123,6 +1163,13 @@ class AppConnectionsServiceClient(metaclass=AppConnectionsServiceClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import beyondcorp_appconnections_v1
 
             def sample_resolve_app_connections():
